@@ -30,4 +30,8 @@ struct rlc_unrpc {
 	long prog;
 };
 
+extern char *curfile_name;
+extern int  curfile_line;
+
+			
 #endif /* !H_PARSE */
