@@ -11,7 +11,7 @@ void rls_unblock();
 
 #define RL_MAX(a,b) ((a) > (b) ? (a) : (b))
 
-extern int rls_need_parse;
+extern volatile int rls_need_parse;
 extern volatile struct pidtab *rls_reaped;
 
 #endif /* !H_SIGNALS */
